@@ -121,12 +121,15 @@ BOOLEAN top;
 
     if (searchfile(fdn, fdfile, &newlibdir, top, (char *)NULL)) {
 #ifdef DEBUG
-	if (Debuguser)
-	    (void)fprintf(stderr, "open fontdesc %s\n", fdfile);
+	if (Debuguser) {
+	    (void)fprintf(stderr, "open fontdesc \"%s\"\n", fdfile);
+	    (void)fprintf(stderr, "    in [%s]+[%s]:[%s]\n",
+			  newlibdir.dir, newlibdir.lcldir, newlibdir.defpath);
+	}
 #endif
 	f = fopen(fdfile, "r");
     } else
-	Fatal("cannot open fontdesc file %s", fdn);
+	Fatal("cannot open fontdesc file \"%s\"", fdn);
     save_fdin = fdin;
     save_libdir = libdir;
     fdname = fdfile;
@@ -214,7 +217,7 @@ char *ext;
 
 #ifdef DEBUG
     if (Debuguser)
-	(void)fprintf(stderr, "search file %s in %s+%s\n",
+	(void)fprintf(stderr, "search file \"%s\" in [%s]+[%s]\n",
 		      f, libdir.dir, libdir.lcldir);
 #endif
     if (strncmp(f, "//", 2) == 0) {
@@ -261,7 +264,8 @@ char *ext;
 
 #ifdef DEBUG
     if (Debuguser)
-	(void)fprintf(stderr, "search file %s in lib %s+%s\n", f, dfp, lcd);
+	(void)fprintf(stderr, "search file \"%s\" in lib [%s]+[%s]\n",
+		      f, dfp, lcd);
 #endif
     if (pathsearchfile(&next, dfp, newf, nld->lcldir, nld->dir, lcd, f, ext)) {
 	nld->defpath = next;
@@ -546,6 +550,8 @@ char *var, *val;
 {
     struct definition *def;
 
+    if (val == NULL)
+	val = "";
     def = NEW(struct definition, "definition");
     def->def_name = var;
     def->def_body = val;
@@ -772,6 +778,20 @@ struct devfile ***np;
     *np = &(df->df_next);
 }
 
+add_include_spec(f, op)
+char *f;
+void (*op)();
+{
+    struct devfile *df;
+
+    df = NEW(struct devfile, "special header");
+    df->df_file = strsave(f);
+    df->df_op = op;
+    df->df_next = NULL;
+    *nextif = df;
+    nextif = &(df->df_next);
+}
+
 add_setup_spec(f, op)
 char *f;
 void (*op)();
@@ -1050,10 +1070,16 @@ struct font_entry *fe;
     char *sb, *se;
     int i, next;
     int null_markchar();
+    static int advice = FALSE;
 
     acca.rawmagfact = rawmagfact = newmagfact = dev_fontmag(fe);
     acca.pv_name = fe->n;
     /* We don't treat the case fe->a != 0 */
+#ifdef DEBUG
+    if (Debuguser)
+	(void)fprintf(stderr, "<- Begin to find font file for %s (mag %d)\n",
+		      fe->n, MAGSIZE(rawmagfact));
+#endif
 
     acca.acc_mode = ACC_EXACT;
     acca.actmagfact = actfact(acca.rawmagfact);
@@ -1061,8 +1087,8 @@ struct font_entry *fe;
 	if ((*(fd->fd_op->fo_access))(fd->fd_path, fe, &acca)) {
 #ifdef DEBUG
 	    if (Debuguser)
-		Warning("Font file for %s (mag %d) found",
-			fe->n, MAGSIZE(rawmagfact));
+		(void)fprintf(stderr, "-> Font file for %s (mag %d) found\n",
+			      fe->n, MAGSIZE(rawmagfact));
 #endif
 	    (*(fd->fd_op->fo_initfontinfo))(fe);
 	    return;
@@ -1078,7 +1104,7 @@ struct font_entry *fe;
 		if ((fd->fd_sub&ACC_SUBST) == 0)
 		    continue;
 		if ((*(fd->fd_op->fo_access))(fd->fd_path, fe, &acca)) {
-		    Warning("Font file for %s: font mag %d replaced by %d",
+		    Warning("-> Font file for %s: font mag %d replaced by %d",
 			    fe->n, fs->fs_reqmag, fs->fs_submag);
 		    (*(fd->fd_op->fo_initfontinfo))(fe);
 		    return;
@@ -1094,7 +1120,7 @@ struct font_entry *fe;
 	    if ((fd->fd_sub&ACC_MAGSTEP) == 0)
 		continue;
 	    if ((*(fd->fd_op->fo_access))(fd->fd_path, fe, &acca)) {
-		Warning("Font file for %s: magnification %d replaced by %d",
+		Warning("-> Font file for %s: magnification %d replaced by %d",
 			fe->n, MAGSIZE(rawmagfact), MAGSIZE(newmagfact));
 		(*(fd->fd_op->fo_initfontinfo))(fe);
 		return;
@@ -1119,8 +1145,8 @@ struct font_entry *fe;
 	if ((*(fd->fd_op->fo_access))(fd->fd_path, fe, &acca)) {
 #ifdef DEBUG
 	    if (Debuguser)
-		Warning("Font file for %s (mag %d) found",
-			fe->n, MAGSIZE(rawmagfact));
+		(void)fprintf(stderr, "-> Font file for %s (mag %d) found\n",
+			      fe->n, MAGSIZE(rawmagfact));
 #endif
 	    (*(fd->fd_op->fo_initfontinfo))(fe);
 	    return;
@@ -1128,9 +1154,12 @@ struct font_entry *fe;
     }
 
     /* allow missing FNT files */
-    Warning("No font file for %s (mag %d)", fe->n, MAGSIZE(rawmagfact));
-    if (Debugoff)
+    Warning("%sNo font file for %s (mag %d)", Debugoff ? "" : "-> ",
+	    fe->n, MAGSIZE(rawmagfact));
+    if (Debugoff && !advice) {
+	advice = TRUE;
 	Warning("(use -d option to know the font file names tried)");
+    }
     fe->fnt_markchar = null_markchar;
     (void)sprintf(fe->name, "null:%s:%d", fe->n, MAGSIZE(rawmagfact));
 }
