@@ -157,7 +157,7 @@ int n;
 	    q--;
 	*++q = '\0';
 	if (p <= q)
-	    ps_add_setup(p);
+	    ps_add_include(p);
 	return;
     }
     if (strncmp(p, "background", 10) == 0) {
